# ===================================================================================
# Date : 2015-02-17
# Modified  : Soraya Arias
# Copyright 2015, INRIA
#
#  The NaoQi CMake configuration file
#
#  Usage from an external project: 
#    In your CMakeLists.txt, add these lines:
#
#    FIND_PACKAGE(NAOQI REQUIRED )
#    INCLUDE_DIRECTORIES(NAOQI_INCLUDE_DIRS)
#    TARGET_LINK_LIBRARIES(MY_TARGET_NAME ${NAOQI_LIBRARIES})   
#
#  If NAOQI related include and libs are not installed in $HOME/.local/share/qi/toolchains/linux directory, you should set NAOQI_SDK_DIRECTORY
#    This file will define the following variables:
#      - NAOQI_LIBRARIES     : The list of libraries to links against.
#      - NAOQI_INCLUDE_DIRS  : The Naoqi related include directories.
#      - NAOQI_FOUND         : Set if Naoqi linux toolchain has been found
#
# ===================================================================================

SET ( NAOQI_FOUND FALSE )

#SET ( NAOQI_TOOLCHAIN_DIR "$ENV{HOME}/.local/share/qi/toolchains/" )

IF ( NOT DEFINED NAOQI_SDK_DIRECTORY )
SET ( NAOQI_SDK_DIRECTORY "/opt/naoqi-sdk-2.1/" CACHE PATH "Path to find Naoqi SDK location" )
ENDIF ()

SET ( NAOQI_SDK_CMD "${NAOQI_SDK_DIRECTORY}/bin/naoqi-bin" )
SET ( NAOQI_SDK_ARG "--version" )
execute_process(COMMAND ${NAOQI_SDK_CMD} ${NAOQI_SDK_ARG} 
  WORKING_DIRECTORY ${PROJECT_SOURCE_DIR}
  RESULT_VARIABLE NAOQI_SDK_VER_STATUS
  OUTPUT_VARIABLE NAOQI_ALL_VERSION
)
string(COMPARE EQUAL "${NAOQI_SDK_VER_STATUS}" 0 cmd_status)
IF ( NOT cmd_status)
  message (STATUS " FGDFGDG" )
ENDIF()
#message(STATUS "naoqi-bin ver: ${NAOQI_SDK_VER_STATUS} ${NAOQI_ALL_VERSION}")

#FIND_PATH ( NAOQI_SYSROOT_INCLUDE_DIR alcommon/almodule.h
#  PATHS ${NAOQI_SDK_DIRECTORY} ${NAOQI_TOOLCHAIN_DIR}
#  PATH_SUFFIXES include atom-ears/libnaoqi-sysroot/include linux64/libnaoqi-sysroot/include linux/libnaoqi-sysroot/include naoqi-sdk/include
#  )

FIND_PATH ( NAOQI_SYSROOT_INCLUDE_DIR alcommon/almodule.h
  PATHS ${NAOQI_SDK_DIRECTORY}
   PATH_SUFFIXES include
 )

#FIND_PATH ( NAOQI_BOOST_INCLUDE_DIR boost/shared_array.hpp
#  PATHS ${NAOQI_SDK_DIRECTORY} ${NAOQI_TOOLCHAIN_DIR}
#  PATH_SUFFIXES include atom-ears/boost/include/boost-1_55 linux64/boost/include/boost-1_55 linux/boost/include/boost-1_55 naoqi-sdk/include 
#  NO_DEFAULT_PATH
#)

FIND_PATH ( NAOQI_BOOST_INCLUDE_DIR boost/shared_array.hpp
  PATHS ${NAOQI_SDK_DIRECTORY}
  PATH_SUFFIXES include
  NO_DEFAULT_PATH
)

## List of libraries naoqi related + boost related
set ( NAOQI_SYSROOT_LIB_LIST qi qitype alaudio alcommon alvalue alvision alerror alproxies alextractor )
foreach(lib ${NAOQI_SYSROOT_LIB_LIST}) 
#FIND_LIBRARY ( NAOQI_SYSROOT_${lib}_LIBRARY ${lib}
#  PATHS ${NAOQI_SDK_DIRECTORY}/lib ${NAOQI_TOOLCHAIN_DIR}
#  PATH_SUFFIXES lib linux64/libnaoqi-sysroot/lib linux/libnaoqi-sysroot/lib naoqi-sdk/lib 
#  )
FIND_LIBRARY ( NAOQI_SYSROOT_${lib}_LIBRARY ${lib}
  PATHS ${NAOQI_SDK_DIRECTORY}
  PATH_SUFFIXES lib
  )
IF (NAOQI_SYSROOT_${lib}_LIBRARY)
  SET (NAOQI_SYSROOT_LIBRARIES ${NAOQI_SYSROOT_LIBRARIES} ${NAOQI_SYSROOT_${lib}_LIBRARY})
ENDIF()
endforeach()

set ( NAOQI_BOOST_LIB_LIST boost_system boost_program_options boost_thread boost_filesystem boost_chrono boost_regex boost_locale ) 
foreach(lib ${NAOQI_BOOST_LIB_LIST})
#FIND_LIBRARY ( NAOQI_BOOST_${lib}_LIBRARY ${lib}
#  PATHS ${NAOQI_SDK_DIRECTORY} ${NAOQI_TOOLCHAIN_DIR} 
#  PATH_SUFFIXES lib linux64/libnaoqi-sysroot/lib linux/libnaoqi-sysroot/lib naoqi-sdk/lib 
#  NO_DEFAULT_PATH
#)
FIND_LIBRARY ( NAOQI_BOOST_${lib}_LIBRARY ${lib}
  PATHS ${NAOQI_SDK_DIRECTORY}
  PATH_SUFFIXES lib
  NO_DEFAULT_PATH
  )
IF (NAOQI_BOOST_${lib}_LIBRARY)
  SET (NAOQI_BOOST_LIBRARIES ${NAOQI_BOOST_LIBRARIES} ${NAOQI_BOOST_${lib}_LIBRARY})
endif()
endforeach()

MESSAGE ( STATUS "NAOQI SYS   LIB DIR = ${NAOQI_SYSROOT_LIBRARIES}" )
MESSAGE ( STATUS "NAOQI BOOST LIB DIR = ${NAOQI_BOOST_LIBRARIES}" )

MESSAGE ( STATUS "NAOQI INCLUDE DIR = ${NAOQI_SYSROOT_INCLUDE_DIR}" )
MESSAGE ( STATUS "NAOQI Boost INCLUDE DIR = ${NAOQI_BOOST_INCLUDE_DIR}" )


IF ( NAOQI_SYSROOT_INCLUDE_DIR AND NAOQI_BOOST_INCLUDE_DIR AND NAOQI_SYSROOT_LIBRARIES AND NAOQI_BOOST_LIBRARIES )
  SET( NAOQI_INCLUDE_DIRS ${NAOQI_SYSROOT_INCLUDE_DIR} ${NAOQI_BOOST_INCLUDE_DIR})
  SET( NAOQI_LIBRARIES ${NAOQI_SYSROOT_LIBRARIES} ${NAOQI_BOOST_LIBRARIES} )
  SET( NAOQI_FOUND TRUE )
ENDIF ()

MESSAGE ( STATUS "NAOQI INCLUDE DIR = ${NAOQI_INCLUDE_DIRS}" )

MARK_AS_ADVANCED (
  NAOQI_INCLUDE_DIRS
  NAOQI_LIBRARIES
  NAOQI_FOUND
  NAOQI_BOOST_LIBRARIES
  NAOQI_BOOST_INCLUDE_DIR
  )

# handle the QUIETLY and REQUIRED arguments
INCLUDE(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS( NAOQI DEFAULT_MSG NAOQI_LIBRARIES NAOQI_INCLUDE_DIRS )
