/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 * 
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/
/*!
* \file Main.cpp
* \brief A short demo to record audio buffer from NAO microphones
*
* \author Fabien Badeig
* \version 1.0
*/

#include "dataproxies.h"
#include <iostream>
#include <stdio.h>
#include <math.h>
#include <vector>
#include <sndfile.hh>

//time include
#include <ctime>

#define PI 3.14159265

const void PrintCurrentTime(){
    char time_str[32];
    std::time_t t = std::time(NULL);

    if (std::strftime(time_str, sizeof(time_str), "[%H:%M:%S] ", std::localtime(&t))){
        std::cerr << time_str;
        return;
    }
    std::cerr << "[unknown time] ";
}

int main(int argc, char *argv[])
{
    const std::string titleWindow("Sound Recorder from Nao microphones");
    std::cerr << "##################################"<< std::endl;
    std::cerr << "Demo to retrieve remotely nao data " << std::endl;
    std::cerr << "##################################"<< std::endl;

    std::cerr << "Press a key to continue" << std::endl;
    getchar();

    int prevts = 0;
    int prevtms = 0;
    int ts = 0;
    int tms = 0;
    int samples = 0;
    int channels = 0;
    int frate = 0;
    short* soundBuffer = new short[4096*4];

    std::vector<short> adata;

    int frecord = 50;
    
    //Loop
    while(frecord >= 0){
        
        //Load nao image in imgCV.data
        PrintCurrentTime();
        std::cerr << "Load sound from Nao microphones" << std::endl;
        DataProxy::getSyncSoundBuffer(ts,tms,samples,channels,frate,soundBuffer);

	if( ts == prevts && tms == prevtms )
	  {
	    continue;
	  }
	
	for(int i = 0; i < samples * channels; i++)
	{
	  adata.push_back((short)soundBuffer[i]);
	}

	prevts = ts;
	prevtms = tms;
	frecord--;
    }

    PrintCurrentTime();
    std::cerr << "Saving audio file" << std::endl;
    std::string fileName("./NaoSound.wav");
    SndfileHandle file = SndfileHandle( fileName, SFM_WRITE, SF_FORMAT_WAV | SF_FORMAT_PCM_16, 4, 48000 ) ;
    file.write( &adata[0], adata.size() ) ;

    PrintCurrentTime();
    std::cerr << "Closing the demo" << std::endl;
    delete[] soundBuffer;
    
    return 0;
}

