/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson
 * Contacts :
 * perception-naolab@inria.fr
 * 
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file naoutils.h
* @author Pelorson Quentin
* @date 2015 Feb 15
* @brief Provides function to create and delete a nao broker.
**/

#ifndef NAOUTILS_H
#define NAOUTILS_H

#ifndef Q_MOC_RUN
#include <alcommon/albroker.h>
#include <alcommon/albrokermanager.h>
#endif // Q_MOC_RUN

boost::shared_ptr<AL::ALBroker> makeLocalBroker(const std::string parentBrokerIP, int parentBrokerPort)
{
    // Name, IP and port of our local broker that talks to NAO's broker:
    const std::string brokerName = "localbroker";
    int brokerPort = 54000;   // FIXME: would be a good idea to look for a free port first
    const std::string brokerIp   = "0.0.0.0";  // listen to anything
    try {
        boost::shared_ptr<AL::ALBroker> broker = AL::ALBroker::createBroker(
                    brokerName,
                    brokerIp,
                    brokerPort,
                    parentBrokerIP,
                    parentBrokerPort,
                    0    // you can pass various options for the broker creation, but default is fine
                );
        std::cout << "createBroker done." << std::endl;
        // ALBrokerManager is a singleton class (only one instance).
        AL::ALBrokerManager::setInstance(broker->fBrokerManager.lock());

        std::cout << "setInstance done." << std::endl;
        AL::ALBrokerManager::getInstance()->addBroker(broker);

        std::cout << "addBroker done." << std::endl;
        return broker;
    }
    catch (const AL::ALError & /* e */) {
        std::cerr << "Faild to connect broker to: " << parentBrokerIP << ":" << parentBrokerPort
                  << std::endl << "Need to create a valid brocker before.\nCheck Nao is turned on.\nNao Ip and port." << std::endl;
        AL::ALBrokerManager::getInstance()->killAllBroker();
        AL::ALBrokerManager::kill();
        //exit(2);
        return boost::shared_ptr<AL::ALBroker>();
    }
}

void deleteLocalBroker()
{
    AL::ALBrokerManager::getInstance()->killAllBroker();
    AL::ALBrokerManager::kill();
}

#endif // NAOUTILS_H
