/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Fabien Badeig, Vincent Drouard
 * Contacts :
 * perception-naolab@inria.fr
 * 
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/*!
 * \file Main.cpp
 * \brief A short demo to use the dataproxy interface
 *        How to access remotely to the nao video data and face detector data
 *
 * \author Fabien Badeig, Vincent Drouard
 * \version 1.0
 */

#include "dataproxies.h"
#include <iostream>
#include <stdio.h>
#include <math.h>

// Opencv includes
#include <opencv2/core/core.hpp>
#include <opencv2/highgui/highgui.hpp>

//time include
#include <ctime>

#define PI 3.14159265

const void PrintCurrentTime()
{
    char time_str[32];
    std::time_t t = std::time(NULL);

    if (std::strftime(time_str, sizeof(time_str), "[%H:%M:%S] ", std::localtime(&t))) {
        std::cerr << time_str;
        return;
    }
    std::cerr << "[unknown time] ";
}

int main(int argc, char *argv[])
{
    const std::string titleWindow("Face detector from Nao data");
    std::cerr << "##################################" << std::endl;
    std::cerr << "Demo to retrieve remotely nao data " << std::endl;
    std::cerr << "##################################" << std::endl;

    std::cerr << "Press a key to continue // Press a key on a display window to stop" << std::endl;
    getchar();

    //Loop condition.
    int key = -1;

    //Image structure
    cv::Mat imgCV;

    int ts = 0;
    int tms = 0;
    int width = 0;
    int height = 0;
    int nbChannels = 0;
    int nbFaces = 0;
    std::vector<float> facesAngles;
    cv::namedWindow(titleWindow, cv::WINDOW_NORMAL);
    //Loop
    while (key < 0) {
        facesAngles.clear();
        imgCV = cv::Mat::zeros(480, 640, CV_8UC3);

        //Load nao image in imgCV.data
        PrintCurrentTime();
        std::cerr << "Load image from Nao" << std::endl;
        DataProxy::getImage(ts, tms, width, height, nbChannels, imgCV.data, DataProxy::BGR);

        //Load Face positions in facesAngles
        PrintCurrentTime();
        std::cerr << "Retrieve faces position" << std::endl;
        DataProxy::getFaceDetectorData(ts, tms, nbFaces, facesAngles);
        double yaw, pitch;
        float currentY = 0, currentP = 0;
        //Draw a circle on the image for each detected face
        for (std::vector<float>::const_iterator itD = facesAngles.begin(); itD != facesAngles.end(); ) {
            yaw = (*itD);
            double yawToPix = (640 / 2) + (640 / 2) * (sin(-1 * (*itD)) / sin((60.97 / 2) * PI / 180));
            ++itD;
            double pitchToPix = (480 / 2) + (480 / 2) * (sin((*itD)) / sin((47.64 / 2) * PI / 180));
            pitch = (*itD);
            ++itD;
            cv::circle(imgCV, cv::Point(yawToPix, pitchToPix), 35, cv::Scalar(0, 0, 255), 4);
            float currentY, currentP;
            // DataProxy::moveHead(yaw, pitch, 0, currentY, currentY);

        }

        //Display.
        cv::imshow(titleWindow, imgCV);
        //Keyboard handler.
        key =  cv::waitKey(5);
    }

    PrintCurrentTime();
    std::cerr << "Closing the demo" << std::endl;

    //Doesn't work well with GTK
    cv::destroyWindow(titleWindow);

    imgCV.release();
    return 0;
}

