/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file getAllMotorInfo.cpp
* @author Fabien Badeig
* @date 2015 May
* @brief Retrieve all info about motor position of the Nao
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/** allPosition = getAllMotorInfo();
  * @return the current position of each Nao motor.
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    if (nrhs != 0) {
        mexPrintf("usage: getAllMotorInfo().\n");
        return;
    }


    float *cPos = new float[26];
    DataProxy::getAllMotorInfo(cPos);

    double *dynamicData;
    dynamicData = (double *)mxMalloc(26 * sizeof(double));

    for (int index = 0; index < 26; index++ ) {
        dynamicData[index] = (double)cPos[index];
    }

    /* Create a 0-by-0 mxArray; you will allocate the memory dynamically */
    plhs[0] = mxCreateNumericMatrix(0, 0, mxDOUBLE_CLASS, mxREAL);

    mxSetPr(plhs[0], dynamicData);
    mxSetM(plhs[0], 26);
    mxSetN(plhs[0], 1);
    delete[] cPos;

}
