/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file getFaceDetectorData.cpp
* @author Quentin Pelorson
* @date 2015 Feb 25
* @brief
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"
#include <vector>

/** [ts tms nbFaces data] = getFaceDetectorData();
  * @param  ts the timestamp. Second part.
  * @param  tms the timestamp. MicroSecond part.
  * @param  nbFaces the of faces detected.
  * @param  data the image coordinate angles :
  *
  * [alpah0 alpah1 alpah2 ....
 *   beta0  beta1  beta2  ....]
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{

    int ts = 0;
    int tms = 0;
    int nbFaces = 0;
    std::vector<float> facesAngles;
    DataProxy::getFaceDetectorData(ts, tms, nbFaces, facesAngles);

    mwSize dims[2] = {2, nbFaces};
    plhs[3] = mxCreateNumericArray(2, dims,  mxDOUBLE_CLASS, mxREAL);
    double *D = (double *)mxGetData(plhs[3]);
    for (int i = 0 ; i < nbFaces ; ++i) {
        D[2 * i] = facesAngles[2 * i];
        D[2 * i + 1] = facesAngles[2 * i + 1];
    }

    plhs[0] = mxCreateDoubleScalar(ts);
    plhs[1] = mxCreateDoubleScalar(tms);
    plhs[2] = mxCreateDoubleScalar(nbFaces);

}
