/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file getImageBuffer.cpp
* @author Pelorson Quentin
* @date 2015 Feb 15
* @brief
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/**[TimeSecond TimeMicroSecond Width Height NbChnls Data] = getImageBuffer();
 * The timestamp is : TimeSecond,TimeMicroSecond
 * Width the width of the image (pixel).
 * Height the height of the image (pixel).
 * NbChnls the number of channels.
 * Data the data buffer :
 * size{Height,Width,NbChnls}
 * Data alignement :
 * Red image first. Green Image second. Blue image last.
 *
 * [ R ][ G ][ B ]
 *
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    int ts = 0;
    int tms = 0;
    int width = DataProxy::IMAGEWIDTH;
    int height = DataProxy::IMAGEHEIGHT;
    int nbChannels = DataProxy::IMAGENBCHANNELS;

    // Build outputs
    mwSize dims[3] = {height, width, nbChannels};
    plhs[5] = mxCreateNumericArray(3, dims,  mxUINT8_CLASS, mxREAL);
    unsigned char *D = (unsigned char *)mxGetData(plhs[5]);

    DataProxy::getImage(ts, tms, width, height, nbChannels, D, DataProxy::MATLABRGB );

    // Build outputs
    plhs[0] = mxCreateDoubleScalar(ts);
    plhs[1] = mxCreateDoubleScalar(tms);
    plhs[2] = mxCreateDoubleScalar(width);
    plhs[3] = mxCreateDoubleScalar(height);
    plhs[4] = mxCreateDoubleScalar(nbChannels);

}
