/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file getMotorInfo.cpp
* @author Fabien Badeig
* @date 2015 May
* @brief Mex function to grab motor position
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/** curruentMotorPosition = getMotorInfo([idma idmb ...], arraySize );
  * @param  array of the motor id
  * @param  size of the array
  * @return the current angle of the specified motors
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    if (nrhs != 2) {
        mexPrintf("usage: getMotorInfo(listJoints, arraySize).\n");
        return;
    }

    int nbElt = mxGetScalar(prhs[1]);

    double *lJoints = mxGetPr(prhs[0]);

    float *cPos = new float[nbElt];
    DataProxy::getMotorInfo(lJoints, nbElt, cPos);

    double *dynamicData;
    dynamicData = (double *)mxMalloc(nbElt * sizeof(double));

    for (int index = 0; index < nbElt; index++ ) {
        dynamicData[index] = (double)cPos[index];
    }

    /* Create a 0-by-0 mxArray; you will allocate the memory dynamically */
    plhs[0] = mxCreateNumericMatrix(0, 0, mxDOUBLE_CLASS, mxREAL);

    mxSetPr(plhs[0], dynamicData);
    mxSetM(plhs[0], nbElt);
    mxSetN(plhs[0], 1);
    delete[] cPos;

}
