/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file getSoundBuffer.cpp
* @author Pelorson Quentin
* @date 2015 Feb 15
* @brief
**/


#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/**[TimeSecond TimeMicroSecond NbSamples NbChannels FreqHz Data] = getSoundBuffer();
 * The timestamp is : TimeSecond,TimeMicroSecond
 * NbSamples the number of samples for each channel.
 * NbChannels the number of channels.
 * FreqHz the Frequency in hz.
 * Data the data buffer :
 * size{NbChannels,NbSamples}
 * example :
 *
 *    s1c1 s2c1 s3c1......
 *    s1c2 s2c2 s3c2......
 *    s1c3 s2c3 s3c3......
 *    s1c4 s2c4 s3c4......
 *
 * Micro
 * 1: RearLeft
 * 2: RearRight
 * 3: FrontLeft
 * 4: FrontRight
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    int ts = 0;
    int tms = 0;
    int nbSamples = DataProxy::SOUNDNBSAMPLES;
    int nbChannels = DataProxy::SOUNDNBCHANNELS;
    int freqHz = DataProxy::SOUNDFREQHZ;

    // Build outputs
    mwSize dims[2] = {nbChannels, nbSamples};
    plhs[5] = mxCreateNumericArray(2, dims,  mxINT16_CLASS, mxREAL);
    short *D = (short *)mxGetData(plhs[5]);
    //mexPrintf("call sound buffer %d %d",nbSamples,nbChannels);

    DataProxy::getSoundBuffer(ts, tms, nbSamples, nbChannels, freqHz, D);

    // Build outputs
    plhs[0] = mxCreateDoubleScalar(ts);
    plhs[1] = mxCreateDoubleScalar(tms);
    plhs[2] = mxCreateDoubleScalar(nbSamples);
    plhs[3] = mxCreateDoubleScalar(nbChannels);
    plhs[4] = mxCreateDoubleScalar(freqHz);
}
