/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file moveHead.cpp
* @author Pelorson Quentin
* @date 2015 Feb 25
* @brief
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/** [absoluteYaw absolutePitch] = getSoundTimeStamp(float YawAngleValue, float PitchAngleValue, bool );
  * @param  YawAngleValue the new ABSOLUTE value for the Yaw angle. LIMIT [-2.0, 2.0]
  * @param  PitchAngleValue the new ABSOLUTE value for the Pitch angle. LIMIT [-0.6, 0.5]
  * @return the absolute value of the yaw and pitch angle after the move command.
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    if (nrhs < 3) {
        mexPrintf("usage : moveHead(YawAngle , PitchAngle , absolute).\n");
        return;
    }

    float yaw = mxGetScalar(prhs[0]);
    float pitch = mxGetScalar(prhs[1]);
    float absoluteYaw = 0.0f;
    float absolutePitch = 0.0f;
    bool absolute = mxGetScalar(prhs[2]);
    bool newCommand = true;

    DataProxy::moveHead(yaw, pitch, absolute, absoluteYaw, absolutePitch);

    plhs[0] = mxCreateDoubleScalar(absoluteYaw);
    plhs[1] = mxCreateDoubleScalar(absolutePitch);

}
