/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file moveTo.cpp
* @author Fabien Badeig
* @date 2015 May
* @brief Mex function to control remotely Nao motors from Matlab
**/

#include <math.h>
#include "mex.h"
#include "dataproxies.h"

/** currentPosition = moveMotorTo([idma idmb ...], [anglema anglemb ...], [speedma speedmb ...], arraySize );
  * @param  Array of the motor id to control
  * @param  Array of the angle to apply on the Nao
  * @param  Array of the time to compute the motion to reach position
  * @param  Array size
  * @return the current angle for each specified motor after the move command.
 **/
void mexFunction(int nlhs, mxArray *plhs[ ], int nrhs, const mxArray *prhs[ ])
{
    if (nrhs != 4) {
        mexPrintf("usage : moveTo(listJoints , listAngles , listSpeeds, arraySize).\n");
        return;
    }

    int nbElt = mxGetScalar(prhs[3]);

    double *lJoints = mxGetPr(prhs[0]);
    double *lAngles = mxGetPr(prhs[1]);
    double *lSpeeds = mxGetPr(prhs[2]);


    float *cPos = new float[nbElt];
    DataProxy::moveMotorTo(lJoints, lAngles, lSpeeds, nbElt, cPos);

    double *dynamicData;
    dynamicData = (double *)mxMalloc(nbElt * sizeof(double));

    for (int index = 0; index < nbElt; index++ ) {
        dynamicData[index] = (double)cPos[index];
    }

    /* Create a 0-by-0 mxArray; you will allocate the memory dynamically */
    plhs[0] = mxCreateNumericMatrix(0, 0, mxDOUBLE_CLASS, mxREAL);

    mxSetPr(plhs[0], dynamicData);
    mxSetM(plhs[0], nbElt);
    mxSetN(plhs[0], 1);
    delete[] cPos;
}
