/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson, Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file naofacedetectordriver.h
* @author Pelorson Quentin
* @date 2015 Feb 26
* @brief
**/

#ifndef NAOFACEDETECTORDRIVER_H
#define NAOFACEDETECTORDRIVER_H

#include <string>
#include <pthread.h>


#include "commondefinitions.h"
#ifndef Q_MOC_RUN
#include <alcommon/almodule.h>
#include <alcommon/alproxy.h>
//#include <alproxies/alfacedetectionproxy.h>
#include <alproxies/almemoryproxy.h>
#endif // Q_MOC_RUN

namespace AL
{
class ALBroker;
}

/**
 * Remote module for synchronized audio and video capture.
 */
class NaoFaceDetectorDriver
{
public:
    /**
     * Default Constructor for modules.
     * @param broker the broker to which the module should register.
     */
    NaoFaceDetectorDriver(boost::shared_ptr<AL::ALBroker> broker);

    /** Destructor.**/
    ~NaoFaceDetectorDriver();

    /**
    * Set the broker to use.
    * @param broker the broker to which the module should register.
    * @return TRUE if connection via broker is successful, FALSE otherwise.
    **/
    bool setBroker(boost::shared_ptr<AL::ALBroker> broker);

    /**
     * Return the state of the connection to the FaceDetector memory block on nao.
     * @return TRUE if connected to nao, FALSE otherwise.
    **/
    bool isConnected();

    /** Get the nao's face detector data and write it in the shared memory.**/
    void getFaceDetectionData();

    void waitLoop();

private:

    /** Proxy to Nao's memory. **/
    AL::ALMemoryProxy *fMemProxy;

    /** Are we currently recording video ? **/
    bool fConnected;

    /** Pointer to the shared memory struct.**/
    FaceDetectorMessage *fSharedMemoryStructPtr;

};

#endif  // NAOFACEDETECTORDRIVER_H

