/* ============================================================
 *
 * This file is a part of the EARS project
 * Copyright (c) INRIA 2015
 *
 * Contributor (s) : Quentin Perlorson, Fabien Badeig
 * Contacts :
 * perception-naolab@inria.fr
 *
 * This file is part of NaoLab.
 *
 * NaoLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * NaoLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with NaoLab. If not, see <http://www.gnu.org/licenses/>.
 *
 * This project is headed by Perception research team at INRIA.
 *
 * ============================================================*/

/**
* @file main.cpp
* @author Pelorson Quentin, Fabien Badeig
* @date 2015 Feb 15
* @brief Main of the naoVideoRemoteDriver application.
**/

#include "naovideodriver.h"
#include "naoutils.h"
#include <iostream>
#include <signal.h>
#include <boost/interprocess/shared_memory_object.hpp>
#include <boost/interprocess/mapped_region.hpp>

using namespace std;

using namespace boost::interprocess;

//System signal handler.
//Use to cleanly exit in case of ctrl+C.
void my_handler(int )
{
    throw std::runtime_error("End of process signal received.");
}

//Print how to use this application.
void usage(char *arg)
{
    std::cerr << "Usage: " << arg << " YOUR_NAO_IP YOUR_NAO_PORT mono/stereo\nDefault Ip = 169.254.80.178 port = 9559" << std::endl;
}

int main(int argc, char *argv[])
{
    //Sparse commande line.
    std::string pIp = "169.254.80.178";
    int pPort = 9559;
    std::string type("mono");
    if (argc != 4) {
        usage(argv[0]);
        if (argc != 1) {
            return 0;
        }
    }
    else {
        pIp = argv[1];
        pPort = atoi(argv[2]);
        type = argv[3];
    }

    //System signal handler.
    //Use to cleanly exit in case of ctrl+C.
    struct sigaction sigIntHandler;
    sigIntHandler.sa_handler = my_handler;
    sigemptyset(&sigIntHandler.sa_mask);
    sigIntHandler.sa_flags = 0;
    sigaction(SIGINT, &sigIntHandler, NULL);

    //Create the local broker.
    //NaoVideoDriver and other nao's tools classes use it to send commend to Nao.
    //<!> Must call deleteLocalBroker() to delete it. <!>
    boost::shared_ptr<AL::ALBroker> broker = makeLocalBroker(pIp, pPort);

    //Create the Nao video streamer object.
    NaoVideoDriver naoVideoDriver(broker, type);

    //Loop condition.
    bool stop = false;
    try {

        naoVideoDriver.initializeCam();

        //Connect to nao's video device and start the frame capture process.
        //By default the asked resolution is VGA(640*480).
        naoVideoDriver.startCapture();

        //Loop
        while (!stop) {
            char c;
            //cout << ">>";
            //wait for a character from the user.
            cin >> c;
            //if 'q' then exit.
            if (c == 'q') {
                stop = true;
            }
        }
        //Stop the video streaming.
        naoVideoDriver.stopCapture();
    }
    catch (const std::exception &error) {
        std::cerr << "Main catchexecption : " << error.what() << std::endl;
        //If still streaming stop it.
        if (naoVideoDriver.isConnected()) {
            naoVideoDriver.stopCapture();
        }

    }
    //Delete the local broker.
    deleteLocalBroker();
    //    shared_memory_object::remove("MySharedMemory");
    return 0;
}

